@@ -21,6 +21,7 @@
 */
 
 #include "base.h"
+#include <stdarg.h>
 #include <errno.h>
 #include <unistd.h>
 #include "unistd-safer.h"
@@ -109,13 +110,6 @@ Ozclose (FILE **p)
   *p = NULL;
 }
 
-void
-Orewind (FILE *f)
-{
-  if (PROB (fseeko (f, 0L, SEEK_SET)))
-    Oerror ();
-}
-
 void
 aflush (FILE *f)
 {
