@@ -22,6 +22,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "findprog.h"
+#include "b-complain.h"
 #include "b-divvy.h"
 
 struct symdef peer_co = { .meaningful = "co", .underlying = NULL };
@@ -33,6 +34,8 @@ find_peer_prog (struct symdef *prog)
     {
       size_t len;
 
+#ifndef EXEEXT
+
       /* Find the driver's invocation directory, once.  */
       if (! BE (invdir))
         {
@@ -40,7 +43,7 @@ find_peer_prog (struct symdef *prog)
           char const *end = strrchr (name, SLASH);
 
           if (!end)
-            abort ();
+            PFATAL ("cannot determine directory (in PATH) of `%s'", name);
           BE (invdir) = intern (PLEXUS, name, end + 1 - name);
           if (name != PROGRAM (invoke))
             free ((void *) name);
@@ -48,6 +51,13 @@ find_peer_prog (struct symdef *prog)
 
       /* Concat the invocation directory with the base name.  */
       accf (PLEXUS, "%s%s", BE (invdir), prog->meaningful);
+
+#else  /* EXEEXT */
+
+      accf (PLEXUS, "%s" EXEEXT, prog->meaningful);
+
+#endif /* EXEEXT */
+
       prog->underlying = finish_string (PLEXUS, &len);
     }
 
