@@ -528,7 +528,14 @@ parse_pattern_letter (char const *s, int c, struct partime *t)
 
     case 'X':                  /* weekday (1=Mon ... 7=Sun) [1-7] */
       s = parse_ranged (s, 1, 1, 7, &t->tm.tm_wday);
+#if 0 /* Apparently *ix convention is to encode this field as 0 (sunday)
+         through 6 (saturday), which relates to the external encoding of
+         1 (monday) through 7 (sunday) not as a constant offset (-1),
+         but as a simple modulo (ext 7 => int 0, else ext => int).  */
       t->tm.tm_wday--;
+#else
+      t->tm.tm_wday %= 7;
+#endif
       break;
 
     case 'x':                  /* weekday name [e.g. "Sun"] */
@@ -631,7 +638,8 @@ merge_partime (struct partime *t, struct partime const *u)
       || conflict (t->tm.tm_mday, u->tm.tm_mday)
       || conflict (t->tm.tm_mon, u->tm.tm_mon)
       || conflict (t->tm.tm_year, u->tm.tm_year)
-      || conflict (t->tm.tm_wday, u->tm.tm_yday)
+      || conflict (t->tm.tm_wday, u->tm.tm_wday)
+      || conflict (t->tm.tm_yday, u->tm.tm_yday)
       || conflict (t->ymodulus, u->ymodulus)
       || conflict (t->yweek, u->yweek)
       || (t->zone != u->zone
@@ -646,7 +654,8 @@ merge_partime (struct partime *t, struct partime const *u)
   merge_ (t->tm.tm_mday, u->tm.tm_mday);
   merge_ (t->tm.tm_mon, u->tm.tm_mon);
   merge_ (t->tm.tm_year, u->tm.tm_year);
-  merge_ (t->tm.tm_wday, u->tm.tm_yday);
+  merge_ (t->tm.tm_wday, u->tm.tm_wday);
+  merge_ (t->tm.tm_yday, u->tm.tm_yday);
   merge_ (t->ymodulus, u->ymodulus);
   merge_ (t->yweek, u->yweek);
 #undef merge_
